const {app, dialog, BrowserWindow, autoUpdater} = require('electron');
var Strings = require('./strings.js');
var strings = new Strings(app.getLocale());
var process = require('process');

var silent = true;

var checkUpdate = function() {
    autoUpdater.checkForUpdates();
};

autoUpdater.on('error', function(event, message) {
    if (silent) {
        silent = false;
        return;
    }
    dialog.showErrorBox(strings.translate('update-error'), message);
});

autoUpdater.on('checking-for-update', function() {
    console.log('checking-for-update');
});

autoUpdater.on('update-available', function() {
    console.log('update-available');
});

autoUpdater.on('update-not-available', function() {
    console.log('update-not-available');
    if (silent) {
        silent = false;
        return;
    }
    dialog.showMessageBox(BrowserWindow.mainWindow, {
        title: strings.translate('update-not-available'),
        message: strings.translate('update-not-available'),
        buttons: [strings.translate('ok')]
    });
});

autoUpdater.on('update-downloaded', function(event, notes, name, date, url, quitAndUpdate) {
    console.log('update-downloaded');

    var ret = dialog.showMessageBox(BrowserWindow.mainWindow, {
        title: strings.translate('update-downloaded'),
        message: name,
        detail: notes,
        buttons: [strings.translate('restart-now'), strings.translate('restart-later')]
    });

    if (ret === 0) {
        if (BrowserWindow.mainWindow) {
            BrowserWindow.mainWindow.forceClose = true;
        }
        quitAndUpdate();
    }
});

var updateUrl = 'https://hedwig.bearychat.com/update';
updateUrl += '?version=' + app.getVersion();
updateUrl += '&platform=' + process.platform;

autoUpdater.setFeedURL(updateUrl);

module.exports = checkUpdate;
