(function() {
    'use strict';

    const {ipcRenderer} = require('electron');
    const hedwig = require('./hedwig');
    const webview = document.querySelector('webview');
    const $modalClose = document.querySelector('#signin-modal .modal-close');

    Array.from(document.querySelectorAll('webview')).forEach(hedwig.bindWebviewEvents);

    if (hedwig.teams.length) {
        hedwig.updateTeamTab();
        hedwig.updateTeamWebviews();
    } else {
        webview.src = hedwig.START_URL;
    }

    $modalClose.addEventListener('click', function() {
        hedwig.nw.closeSwitchModal();
    });

    ipcRenderer.on('reload', function() {
        hedwig.reload();
    });

    ipcRenderer.on('focus', function() {
        hedwig.focusTeam(hedwig.curTeamId);
    });

    ipcRenderer.on('blur', function() {
        hedwig.blurTeam(hedwig.curTeamId);
    });

    ipcRenderer.on('switch-team', function() {
        hedwig.nw.switchTeam();
    });

    ipcRenderer.on('history-forward', function() {
        hedwig.nw.historyForward();
    });

    ipcRenderer.on('history-back', function() {
        hedwig.nw.historyBack();
    });

    var fs = require('fs');

    ipcRenderer.on('upload-file', function(event, fileName, filePath) {
        fs.readFile(filePath, function(err, data) {
            if (err) {
                console.error('error opening file.');
                console.error(err);
                return;
            }

            fs.unlink(filePath, function() {});

            uploadFile(data, fileName);
        });
    });

    ipcRenderer.on('win-screenshot', function(event, fileName) {
        const {clipboard} = require('electron');
        const image = clipboard.readImage();
        uploadFile(image.toPng(), fileName);
    });

    function uploadFile(data, fileName) {
        var byteArray = new Uint8Array(data);
        const type = 'image/png';
        var currentWebviewId = 'frame-' + hedwig.curTeamId;
        var $currentWebview = document.querySelector(`webview[id="${currentWebviewId}"]`);
        if ($currentWebview) {
            $currentWebview.send('hedwig', {
                type: 'upload-file',
                data: byteArray,
                fileName,
                fileType: type
            });
            ipcRenderer.send('show');
        }
    }

    window.onbeforeunload = function() {
        localStorage.teams = JSON.stringify(hedwig.teams);
        localStorage.current_team_id = hedwig.curTeamId;
    };
})();
