(function() {
    'use strict';

    const remote = require('electron').remote;
    const Strings = require('../strings');
    const strings = new Strings(remote.app.getLocale());
    document.title = strings.translate("settings");
    document.body.querySelector("#shortcut-setting").innerText = strings.translate("shortcut-setting");
    document.body.querySelector("#screenshot-label").innerText = strings.translate("screenshot");
    document.body.querySelector("#download-setting").innerText = strings.translate("download-setting");
    document.body.querySelector("#location-label").innerText = strings.translate("location");
    document.body.querySelector("#btn-choose-location").innerText = strings.translate("change");
    document.body.querySelector("#btn-restore").innerText = strings.translate("restore-default");
    
    const preference = remote.require('./preference');

    var $screenshotShortcut = document.body.querySelector('#screenshot-shortcut');
    $screenshotShortcut.value = preference.getScreenshotKey();
    $screenshotShortcut.addEventListener('keydown', (event) => {
        event.preventDefault();
        var keys = require('../shortcut-detector').detect(event);
        if (keys.length > 1) {
            $screenshotShortcut.value = keys.join(' + ');
            require('electron').ipcRenderer.send('change-screenshot-shortcut', $screenshotShortcut.value);
        }
    });

    var $btnCancelScreenshotShortcut = document.body.querySelector('#btn-cancel-screenshot-shortcut');
    $btnCancelScreenshotShortcut.addEventListener('click', (event) => {
        require('electron').ipcRenderer.send('cancel-screenshot-shortcut');
        $screenshotShortcut.value = "";
    });

    var $downloadLocation = document.body.querySelector("#download-location");
    
    $downloadLocation.value = preference.getDownloadLocation();
    var $btnChooseLocation = document.body.querySelector('#btn-choose-location');
    $btnChooseLocation.addEventListener('click', (event) => {
        const {dialog} = require('electron').remote;
        dialog.showOpenDialog({properties: ['openDirectory']}, (location) => {
            if (location) {
                $downloadLocation.value = location[0];
                preference.setDownloadLocation(location[0]);
            }
        });
    });

    var $btnRestore = document.body.querySelector("#btn-restore");
    $btnRestore.addEventListener('click', (event) => {
        require('electron').ipcRenderer.send('change-screenshot-shortcut', preference.getDefaultScreenshotKey());
        $screenshotShortcut.value = preference.getDefaultScreenshotKey();
        preference.setDownloadLocation(preference.getDefaultDownloadLocation());
        $downloadLocation.value = preference.getDefaultDownloadLocation();
    });
})();