'use strict';


const {webFrame} = require('electron');

// to support old robot avatar
webFrame.registerURLSchemeAsSecure('http');

// disable zoom
webFrame.setZoomLevelLimits(1, 1);

// initialize spellchecker
if (process.platform === 'darwin') {
    webFrame.setSpellCheckProvider("en-US", true, {
        spellCheck: function (text) {
            return !(require('spellchecker').isMisspelled(text));
        }
    });
}

// inject Notification when necessary
if (process.platform === 'win32') {
    const osVer = require('os').release();
    const mainVer = Number(osVer.split('.')[0]) || 9999;

    if (mainVer <= 8) {
        window.Notification = require('./BearyNotification');
    }
}

// 模拟一个相对安全的仿 node 环境
const nodeRequire = require;
const nodeProcess = process;

// 包在 setImmediate 里防止被 preload 后续的删除全局变量过程给删掉
setImmediate(() => {
    window.require = (module) => {
        if (module === 'electron') {
            return nodeRequire(module);
        }
    };

    window.process = {
        type: nodeProcess.type
    };
});
