'use strict';

const Configstore = require('configstore');
const manifest = require('./package.json');
const {app} = require('electron');

const SCREENSHOT_KEY = 'screenshot-key';
const DOWNLOAD_LOCATION_KEY = 'download-location';

class Preference {

    constructor() {
        this.conf = new Configstore(manifest.name);
    }

    getDefaultScreenshotKey() {
        return process.platform === 'darwin' ? 'Command + Control + S' : 'Control + Alt + S';
    }

    setScreenshotKey(key) {
        this.conf.set(SCREENSHOT_KEY, key);
    }

    getScreenshotKey() {
        var key = this.conf.get(SCREENSHOT_KEY);
        if (typeof key === 'undefined') {
            key = this.getDefaultScreenshotKey();
        }
        return key;
    }

    getDefaultDownloadLocation() {
        return app.getPath('downloads');
    }

    setDownloadLocation(location) {
        this.conf.set(DOWNLOAD_LOCATION_KEY, location);
    }

    getDownloadLocation() {
        var location = this.conf.get(DOWNLOAD_LOCATION_KEY);
        if (!location) {
            location = this.getDefaultDownloadLocation();
        }
        return location;
    }
}

module.exports = new Preference();