'use strict';

const safeKeys = {
    27: "Esc",
    37: "Left",
    38: "Up",
    39: "Right",
    40: "Down",
    59: ";",
    61: "=",
    96: "0",
    97: "1",
    98: "2",
    99: "3",
    100: "4",
    101: "5",
    102: "6",
    103: "7",
    104: "8",
    105: "9",
    106: "*",
    107: "+",
    109: "-",
    110: ".",
    111: "/",
    173: "-",
    186: ";",
    187: "=",
    188: ",",
    189: "-",
    190: ".",
    191: "/",
    192: "`",
    219: "[",
    220: "\\",
    221: "]",
    222: "'"
};

const ctrlKeys = [13, 16, 17, 18, 91, 93]; // Shift, Shift, Control, Alt, Command, Command

class ShortcutDetector {
    static detect(event) {
        var keys = [];
        if (event.ctrlKey) {
            keys.push('Control');
        }
        if (event.metaKey) {
            keys.push('Command');
        }
        if (event.shiftKey) {
            keys.push('Shift');
        }
        if (event.altKey) {
            keys.push('Alt');
        }
        var keyCode = event.keyCode ? event.keyCode : event.which;

        if (keys.length > 0 && ctrlKeys.indexOf(keyCode) < 0) {
            if ('A'.charCodeAt(0) <= keyCode && keyCode <= 'Z'.charCodeAt(0)) {
                keys.push(String.fromCharCode(keyCode));
                return keys;
            } else if (safeKeys[keyCode]) {
                keys.push(safeKeys[keyCode]);
                return keys;
            }
        }
        return [];
    }
}

module.exports = ShortcutDetector;